RouterController

Struct RouterController 

pub struct RouterController { /* private fields */ }
Reactive navigation controller for one shard tree.

Implementations

Source

impl RouterController

pub fn new() -> Self

Create an empty controller.

pub fn with_root(root_dest: impl RouterDestination + 'static) -> Self

Create a controller seeded with a root destination.

pub fn with_root_shared(root_dest: Arc<dyn RouterDestination>) -> Self

Create a controller seeded with a shared root destination.

pub fn version(&self) -> u64

Monotonic routing version.

pub fn push<T: RouterDestination + 'static>(&mut self, destination: T)

Push a destination onto the stack.

pub fn push_shared(&mut self, destination: Arc<dyn RouterDestination>)

Push a shared destination onto the stack.

pub fn pop(&mut self) -> Option<Arc<dyn RouterDestination>>

Pop the top destination from the stack.

Returns None if the stack is empty.

pub fn replace<T: RouterDestination + 'static>( &mut self, destination: T, ) -> Option<Arc<dyn RouterDestination>>

Replace the top destination.

If the stack is empty, this behaves like Self::push.

pub fn replace_shared( &mut self, destination: Arc<dyn RouterDestination>, ) -> Option<Arc<dyn RouterDestination>>

Replace the top destination with a shared destination.

pub fn is_empty(&self) -> bool

Whether the stack is empty.

pub fn len(&self) -> usize

Number of destinations in the stack.

pub fn last(&self) -> Option<&dyn RouterDestination>

Top destination.

pub fn exec_current(&self) -> bool

Execute the top destination.

Returns false when the stack is empty.

pub fn init_or_get<T, F, R>(&self, id: &str, f: F) -> R
where T: Default + Send + Sync + 'static, F: FnOnce(ShardState<T>) -> R,

Get or initialize route-scoped state and provide it to f.

pub fn init_or_get_with_lifecycle<T, F, R>( &self, id: &str, life_cycle: ShardStateLifeCycle, f: F, ) -> R
where T: Default + Send + Sync + 'static, F: FnOnce(ShardState<T>) -> R,

Get or initialize state for a lifecycle scope and provide it to f.

pub fn clear(&mut self)

Clear all destinations from the stack.

pub fn reset(&mut self, root_dest: impl RouterDestination + 'static)

Clear all destinations and push a new root destination.

pub fn reset_shared(&mut self, root_dest: Arc<dyn RouterDestination>)

Clear all destinations and push a shared root destination.